Contributing
############


We're glad that you are considering **joining the team** and the **community of open-science**. You can find step-by-step guides below that will show you how to make a perfect first contribution.

**All people are very much welcome to contribute to code, documentation, testing and suggestions.**

This package aims at being beginner-friendly. Even if you're new to this open-source way of life, new to coding and GitHub stuff, we encourage you to try submitting pull requests (PRs). 

- *"I'd like to help, but I'm not good enough with programming yet"*

It's alright, don't worry! You can always dig in the code, in the documentation or tests. There are always some typos to fix, some docs to improve, some details to add, some code lines to document, some tests to add... Just explore the code structure, find where functions are located, where documentation is written, where tests are made, and see what you can fix. **Even the smaller PRs are appreciated**.

- *"I don't know how to code at all :("*

You can still contribute to the `documentation <https://github.com/neuropsychology/NeuroKit/tree/master/docs>`_ by creating tutorials, help and info!

- *"I'd like to help, but I don't know where to start"*

You can look around the `issue section <https://github.com/neuropsychology/NeuroKit/issues>`_ to find some features / ideas / bugs to start working on. You can also open a new issue **just to say that you're there, interested in helping out**. We might have some ideas adapted to your skills.

- *"I'm not sure if my suggestion or idea is worthwhile"*

Enough with the impostor syndrome! All suggestions and opinions are good, and even if it's just a thought or so, it's always good to receive feedback.

- *"Why should I waste my time with this? Do I get any credit?"*

Software contributions are getting more and more valued in the academic world, so it is a good time to collaborate with us! All contributors will be added within the `authors list <https://neurokit2.readthedocs.io/en/latest/credits.html>`_. We're also very keen on including them to eventual academic publications.


Anyway, starting is the most important! You will then enter a *whole new world, a new fantastic point of view*... So fork this repo, do some changes and submit them. We will then work together to make the best out of it 💪



**Contributing Guides:**

.. toctree::
   :maxdepth: 1
   
   understanding
   contributing
   first_contribution
   
